# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/boomee/influencer/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/boomee/influencer/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Boomee\\Influencer\\": "packages/boomee/influencer/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Boomee\Influencer\Providers\InfluencerServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Influencer'  => Boomee\Influencer\Facades\Influencer::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Boomee\\InfluencerTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Boomee\Influencer\Providers\InfluencerServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Boomee\Influencer\Providers\InfluencerServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Boomee\Influencer\Providers\InfluencerServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/influencer/{modulename}

**User**

    http://path-to-route-folder/user/influencer/{modulename}

**Public**

    http://path-to-route-folder/influencers


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/influencer/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/influencer/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/influencer/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/influencer/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/influencer/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/influencer/{modulename}/{slug}
    METHOD: GET