<?php

namespace Boomee\Influencer\Policies;

use Litepie\User\Contracts\UserPolicy;
use Boomee\Influencer\Models\Influencer;

class InfluencerPolicy
{

    /**
     * Determine if the given user can view the influencer.
     *
     * @param UserPolicy $user
     * @param Influencer $influencer
     *
     * @return bool
     */
    public function view(UserPolicy $user, Influencer $influencer)
    {
        if ($user->canDo('influencer.influencer.view') && $user->isAdmin()) {
            return true;
        }

        return $influencer->user_id == user_id() && $influencer->user_type == user_type();
    }

    /**
     * Determine if the given user can create a influencer.
     *
     * @param UserPolicy $user
     * @param Influencer $influencer
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('influencer.influencer.create');
    }

    /**
     * Determine if the given user can update the given influencer.
     *
     * @param UserPolicy $user
     * @param Influencer $influencer
     *
     * @return bool
     */
    public function update(UserPolicy $user, Influencer $influencer)
    {
        if ($user->canDo('influencer.influencer.edit') && $user->isAdmin()) {
            return true;
        }

        return $influencer->user_id == user_id() && $influencer->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given influencer.
     *
     * @param UserPolicy $user
     * @param Influencer $influencer
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Influencer $influencer)
    {
        return $influencer->user_id == user_id() && $influencer->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given influencer.
     *
     * @param UserPolicy $user
     * @param Influencer $influencer
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Influencer $influencer)
    {
        if ($user->canDo('influencer.influencer.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given influencer.
     *
     * @param UserPolicy $user
     * @param Influencer $influencer
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Influencer $influencer)
    {
        if ($user->canDo('influencer.influencer.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
