<?php

namespace Boomee\Influencer\Policies;

use Litepie\User\Contracts\UserPolicy;
use Boomee\Influencer\Models\Social;

class SocialPolicy
{

    /**
     * Determine if the given user can view the social.
     *
     * @param UserPolicy $user
     * @param Social $social
     *
     * @return bool
     */
    public function view(UserPolicy $user, Social $social)
    {
        if ($user->canDo('influencer.social.view') && $user->isAdmin()) {
            return true;
        }

        return $social->user_id == user_id() && $social->user_type == user_type();
    }

    /**
     * Determine if the given user can create a social.
     *
     * @param UserPolicy $user
     * @param Social $social
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('influencer.social.create');
    }

    /**
     * Determine if the given user can update the given social.
     *
     * @param UserPolicy $user
     * @param Social $social
     *
     * @return bool
     */
    public function update(UserPolicy $user, Social $social)
    {
        if ($user->canDo('influencer.social.edit') && $user->isAdmin()) {
            return true;
        }

        return $social->user_id == user_id() && $social->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given social.
     *
     * @param UserPolicy $user
     * @param Social $social
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Social $social)
    {
        return $social->user_id == user_id() && $social->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given social.
     *
     * @param UserPolicy $user
     * @param Social $social
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Social $social)
    {
        if ($user->canDo('influencer.social.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given social.
     *
     * @param UserPolicy $user
     * @param Social $social
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Social $social)
    {
        if ($user->canDo('influencer.social.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
