<?php

namespace Boomee\Influencer\Providers;

use Illuminate\Support\ServiceProvider;

class InfluencerServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'influencer');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'influencer');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerInfluencer();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerInfluencer()
    {
        $this->app->bind('influencer', function($app) {
            return new Influencer($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Influencer', 'Lavalite\Influencer\Facades\Influencer');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('boomee.influencer', function ($app) {
            return $this->app->make('Boomee\Influencer\Influencer');
        });

        // Bind Influencer to repository
        $this->app->bind(
            'Boomee\Influencer\Interfaces\InfluencerRepositoryInterface',
            \Boomee\Influencer\Repositories\Eloquent\InfluencerRepository::class
        );
        // Bind Social to repository
        $this->app->bind(
            'Boomee\Influencer\Interfaces\SocialRepositoryInterface',
            \Boomee\Influencer\Repositories\Eloquent\SocialRepository::class
        );

        $this->app->register(\Boomee\Influencer\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Boomee\Influencer\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and influencer's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'boomee.influencer'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeInfluencer::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['boomee.influencer'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('boomee/influencer.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/influencer')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/influencer')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
