<?php

namespace Boomee\Influencer\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Boomee\Influencer\Models\Influencer;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Boomee\Influencer\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/influencer/influencer/*')) {
            Route::bind('influencer', function ($influencer) {
                $influencerrepo = $this->app->make('Boomee\Influencer\Interfaces\InfluencerRepositoryInterface');
                return $influencerrepo->findorNew($influencer);
            });
        }

        if (Request::is('*/influencer/social/*')) {
            Route::bind('social', function ($social) {
                $socialrepo = $this->app->make('Boomee\Influencer\Interfaces\SocialRepositoryInterface');
                return $socialrepo->findorNew($social);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
